@@ -19,7 +19,9 @@ from datamodel_code_generator.model.pydantic.imports import (
     IMPORT_CONSTR,
     IMPORT_EMAIL_STR,
     IMPORT_IPV4ADDRESS,
+    IMPORT_IPV4NETWORKS,
     IMPORT_IPV6ADDRESS,
+    IMPORT_IPV6NETWORKS,
     IMPORT_NEGATIVE_FLOAT,
     IMPORT_NEGATIVE_INT,
     IMPORT_NON_NEGATIVE_FLOAT,
@@ -86,6 +88,8 @@ def type_map_factory(
         ),
         Types.ipv4: data_type.from_import(IMPORT_IPV4ADDRESS),
         Types.ipv6: data_type.from_import(IMPORT_IPV6ADDRESS),
+        Types.ipv4_network: data_type.from_import(IMPORT_IPV4NETWORKS),
+        Types.ipv6_network: data_type.from_import(IMPORT_IPV6NETWORKS),
         Types.boolean: data_type(type='bool'),
         Types.object: data_type.from_import(IMPORT_ANY, is_dict=True),
         Types.null: data_type.from_import(IMPORT_ANY, is_optional=True),
