@@ -95,7 +95,9 @@ json_schema_data_formats: Dict[str, Dict[str, Types]] = {
         'uri-reference': Types.string,
         'hostname': Types.hostname,
         'ipv4': Types.ipv4,
+        'ipv4-network': Types.ipv4_network,
         'ipv6': Types.ipv6,
+        'ipv6-network': Types.ipv6_network,
         'decimal': Types.decimal,
         'integer': Types.integer,
     },
@@ -329,6 +331,7 @@ class JsonSchemaParser(Parser):
         use_annotated: bool = False,
         use_non_positive_negative_number_constrained_types: bool = False,
         original_field_name_delimiter: Optional[str] = None,
+        use_double_quotes: bool = False,
     ):
         super().__init__(
             source=source,
@@ -375,6 +378,7 @@ class JsonSchemaParser(Parser):
             use_annotated=use_annotated,
             use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
             original_field_name_delimiter=original_field_name_delimiter,
+            use_double_quotes=use_double_quotes,
         )
 
         self.remote_object_cache: DefaultPutDict[str, Dict[str, Any]] = DefaultPutDict()
