@@ -184,6 +184,7 @@ class OpenAPIParser(JsonSchemaParser):
         use_annotated: bool = False,
         use_non_positive_negative_number_constrained_types: bool = False,
         original_field_name_delimiter: Optional[str] = None,
+        use_double_quotes: bool = False,
     ):
         super().__init__(
             source=source,
@@ -230,6 +231,7 @@ class OpenAPIParser(JsonSchemaParser):
             use_annotated=use_annotated,
             use_non_positive_negative_number_constrained_types=use_non_positive_negative_number_constrained_types,
             original_field_name_delimiter=original_field_name_delimiter,
+            use_double_quotes=use_double_quotes,
         )
         self.open_api_scopes: List[OpenAPIScope] = openapi_scopes or [
             OpenAPIScope.Schemas
