@@ -63,6 +63,7 @@ class Modular(Protocol):
 class DataType(_BaseModel):
     class Config:
         extra = "forbid"
+        copy_on_model_validation = False
 
     type: Optional[str]
     reference: Optional[Reference]
@@ -313,7 +314,9 @@ class Types(Enum):
     uri = auto()
     hostname = auto()
     ipv4 = auto()
+    ipv4_network = auto()
     ipv6 = auto()
+    ipv6_network = auto()
     boolean = auto()
     object = auto()
     null = auto()
